/***************************************************************************
 * MoioChart Library - graphs and charts made easy                         *
 * Copyright (C) 2005 by Silvio Moioli                                     *
 * silvio@moioli.net, http://www.moioli.net                                *  
 *                                                                         *
 * This program is free software; you can redistribute it and/or           *
 * modify it under the terms of the GNU General Public License             *
 * as published by the Free Software Foundation; either version 2          *
 * of the License, or (at your option) any later version.                  *
 *                                                                         *
 * This program is distributed in the hope that it will be useful,         *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 * GNU General Public License for more details.                            *
 *                                                                         *
 * You should have received a copy of the GNU General Public License       *
 * along with this program; if not, write to the Free Software             *
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,              *
 * MA  02110-1301, USA.                                                    *
 ***************************************************************************/

package net.moioli.chart;

/**
 * An object which can be drawn on a DefaultChart.
 * 
 * @author Silvio Moioli
 * @version 2005/10/5
 */
public interface DrawableI {
    /**
     * This method is automatically called by DefaultChart to draw the objects it
     * contains, so end users should never call drawMe directly. Inside this
     * method there must be all the code to draw the object on a DefaultChart, and all
     * the operations which involve scaling should be done via the passed Scale
     * object.
     * 
     * @param g
     *            the surface where this object will be drawn
     * @param s
     *            the DefaultChart's Scale object
     * @param c
     *            the color to be used for drawing
     */
    void drawMe(GraphicsI g, Scale s, Object c);

    /**
     * Returns the minimum y value that should be represented in the DefaultChart for
     * this object to be drawn properly. <br />
     * If the object will be drawn indipendently from the y values represented
     * in the DefaultChart, this method should return Double.NaN.
     * 
     * @param minX
     *            the minimum x value represented in this DefaultChart
     * @param maxX
     *            the maximum x value represented in this DefaultChart
     * @return the minimum y value or NaN
     */
    double minY(double minX, double maxX);

    /**
     * Returns the maximum y value that should be represented in the DefaultChart for
     * this object to be drawn properly. <br />
     * If the object will be drawn indipendently from the y values represented
     * in the DefaultChart, this method should return Double.NaN.
     * 
     * @param minX
     *            the minimum x value represented in this DefaultChart
     * @param maxX
     *            the maximum x value represented in this DefaultChart
     * @return the maximum y value or NaN
     */
    double maxY(double minX, double maxX);
}